Lua_VipPanel = class("Lua_VipPanel", Lua_DisplayObject);

function Lua_VipPanel:ctor(p)
    self:superCall("ctor", p, "VipPanel_skin");
end

function Lua_VipPanel:buildPanel()
    self:superCall("buildPanel")

    self:addLuaEvent("VIPLEVEL_SELECT", self, self.updatePanelInfo);
    self:addLuaEvent("SET_VIPPANEL_INFO", self, self.setPanelData);
    self:addLuaEvent("GET_VIPGIFT_SUCCEED", self, self.setPanelEvent);
end

function Lua_VipPanel:buildShowItem()
    self:superCall("buildShowItem");
    self.goBtn:setEnable(false)

    self.btnIndex = -1;
    self.bar.txt:setLocation(0, 1, 0);
    self.bg_1:SetDimensions(720, 720 + self.adaptHeight);
    self.bg_2:SetDimensions(499, 741 + self.adaptHeight);
    self.bg_3:SetDimensions(465, 299 + self.adaptHeight);

    self.btnList = Lua_DragList.new(self.content, 207, 715 + self.adaptHeight, Lua_AxisDefine.Vertical);
    self.btnList:setLocation(-252.5, -250, 0);
    self.btnList:setListCell(Lua_VipBtnItem, 207, 128, 1);
    self.btnList:setCellSpacing(0, 4);
    
    self.dragContainer = Lua_DragContainer.new(self.content, 450, 280 + self.adaptHeight, Lua_AxisDefine.Vertical);
    self.dragContainer:setLocation(106, -125, 0);
    self.dragContainer:addSubContainer(Lua_VipPrivilegeItem);

    self.rewardList = Lua_DragList.new(self.content, 340, 80, Lua_AxisDefine.Horizontal);
    self.rewardList:setRectAnchor(7);
    self.rewardList:setLocation(105, 332, 0);
    self.rewardList:setListCell(Lua_VipRewardItem, 80, 80, 1);
    self.rewardList:setCellSpacing(5, 0);

    self.buyBtn:addClickFuntion(self,self.onBuyBtnClick);
    self.tipIcon:addClickFuntion(self, self.onTipIconClick);
    self.goBtn:addClickFuntion(self, self.onGoBtnClick);

    self:setPanelEvent();
end

function Lua_VipPanel:dispose()
    if self.btnList ~= nil then
        self.btnList:dispose();
        self.btnList = nil;
    end
    if self.dragContainer ~= nil then
        self.dragContainer:dispose();
        self.dragContainer = nil;
    end
    if self.rewardList ~= nil then
        self.rewardList:dispose();
        self.rewardList = nil;
    end
    if self.vipNum ~= nil then
        self.vipNum:dispose();
        self.vipNum = nil;
    end
    self.costVo = nil;
    self.data = nil;
    self:superCall("dispose");
end

function Lua_VipPanel:onScreenResize(adaptHeight)
    self:superCall("onScreenResize", adaptHeight);

    self.bg_1:SetDimensions(720, 720 + adaptHeight);
    self.bg_2:SetDimensions(499, 741 + adaptHeight);
    self.bg_3:SetDimensions(465, 299 + adaptHeight);

    self.btnList:setContentRect(207, 715 + adaptHeight);
    self.dragContainer:setContentRect(450, 280 + adaptHeight);

    if self.dragContainer ~= nil then
        self.dragContainer.canDrag = not self.dragContainer.bDragEnd;
    end
end

function Lua_VipPanel:setPanelEvent()
    Lua_ProxyManager.getProxy("Lua_VipProxy"):sGetVipPanelInfo();
end

function Lua_VipPanel:setPanelData()
    self.isUpdate = true;
    local data = DataCenter.vipData;

    self.btnList:setArrayData(data.vipVoArr);
    if self.btnIndex == -1 then
        local selectIndex = data:getBtnSelectIndex();
        self.btnList:moveToIndex(selectIndex, true);
        self.btnList:setSelectClick(selectIndex);
        self.btnList:setSelected(selectIndex);
    else
        self.btnList:moveToIndex(self.btnIndex, true);
        self.btnList:setSelectClick(self.btnIndex);
        self.btnList:setSelected(self.btnIndex);
    end

    local vipInfo;
    if data.level >= data.maxVipLevel then
        vipInfo = data:getVipVoByLevel(data.maxVipLevel);
    else
        vipInfo = data:getVipVoByLevel(data.level + 1);
    end

    self.bar:setMaxValue(vipInfo.target);
    self.bar:setValue(data.vipExp);
    if data.level >= data.maxVipLevel and data.vipExp >= vipInfo.target then
        self.bar:setText(vipInfo.target .. "/" .. vipInfo.target);
    else
        self.bar:setText(data.vipExp .. "/" .. vipInfo.target);
    end

    self.levelTxt.text = data.level;
    if data.level == 0 then
        self.titleName:setAltas("vip_atlas", "ui_vip_title_12");
        self.titleName:SetDimensions(138, 77);
        self.titleName:setLocation(-232, -152, 0);
        if self.vipNum ~= nil then
            self.vipNum:setEnable(false);
        end
    else
        self.titleName:setAltas("vip_atlas", "ui_vip_title_11");
        self.titleName:SetDimensions(174, 68);

        if self.vipNum == nil then
            self.vipNum = Lua_NumberImage.new(self.content);
            self.vipNum.preStr = "ui_vip_title_0";
            self.vipNum.pivot = 1;
            self.vipNum.numOffsetX = -30;
            self.vipNum:setRectAnchor(1);
        end
        self.vipNum:setEnable(true);
        self.vipNum.num = data.level;
        if data.level > 9 then
            self.vipNum:setLocation(-370, -150, 0);
            self.titleName:setLocation(-370 + self.vipNum.totalWidth + 174 / 2 + 15, -152, 0);
        else
            self.vipNum:setLocation(-360, -150, 0);
            self.titleName:setLocation(-360 + self.vipNum.totalWidth + 174 / 2 + 15, -152, 0);
        end
    end
end

function Lua_VipPanel:updatePanelInfo(data)
    if self.btnIndex == data.id + 1 and self.isUpdate == false then
        return;
    end
    self.btnIndex = data.id + 1;
    self.isUpdate = false;
    self.data = data;

    if data.id == 0 then
        self.titleTxt:setLangValue(320000);
    else
        self.titleTxt.text = LanUtil.formateStr(320001, data.id);
    end

    local str;
    if data.rewardState == 0 then
        self.lockTxt:setEnable(true);
        str = spliceIconStrById(Lua_ResourcesDefine.VIP_EXP);
        self.lockTxt.text = LanUtil.formateStr(320002, str, data.target);

        self.buyObj:SetActive(false);
    else
        self.lockTxt:setEnable(false);
        self.buyObj:SetActive(true);

        if self.costVo == nil then
            self.costVo = Lua_ToolVo.createToolVo(data.last_cost[1]);
        else
            self.costVo:setData(data.last_cost[1]);
        end
        self.costIcon:setAltas(self.costVo.iconAtlas, self.costVo.iconSprite);
        self.costIcon:SetDimensions(self.costVo.iconWidth, self.costVo.iconHeight);
        self.costCount.text = data.last_cost[2];
        self.costCount:resetSize();
        self.priceLine:SetDimensions(self.costCount.width, 2);
        self.discountBg:setEnable(data.discount > 0);
        self.discountTxt:setEnable(data.discount > 0);
        self.discountTxt.text = LanUtil.formateStr(320004, data.discount);

        if data.rewardState == 1 then
            self.buyBtn:setStyle(5);
            str = spliceIconStrById(data.buy_cost[1]);
            self.buyBtn.label = LanUtil.formateStr(320005, str, data.buy_cost[2]);
            self.buyBtn:setMouseEnable(true);
        else
            self.buyBtn:setStyle(7);
            self.buyBtn:setLangValue(320006);
            self.buyBtn:setMouseEnable(false);
        end
    end

    self.dragContainer:setChildData(data.privilege_des);
    self.dragContainer:moveToIndex(1, true, false);
    self.dragContainer.canDrag = not self.dragContainer.bDragEnd;

    local rewardInfo = data.vip_reward;
    local len = #rewardInfo;
    if len <= 5 then
        self.rewardList:setContentRect(80 * len + 5 * (len - 1), 80);
    else
        self.rewardList:setContentRect(420, 80);
    end
    self.rewardList.canDrag = len > 5;
    self.rewardList:setArrayData(rewardInfo);
end

function Lua_VipPanel:onBuyBtnClick(go)
    if self.data.rewardState == 0 then
        return;
    end

    if DataCenter.moneyData:isMoneyEnough(Lua_ResourcesDefine.DIAMOND, self.data.buy_cost[2], true, false, false) == false then
        DataCenter.funcPathUtil:gotoFunction(1024);
        return;
    end
    Lua_ProxyManager.getProxy("Lua_VipProxy"):sGetGiftReward(self.data.id);
end

function Lua_VipPanel:onTipIconClick(go)
    local tipsData = { des = LanUtil.getValue(320007), posX = 205, posY = -245 };
    Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_VipPanel:onGoBtnClick(go)
    local funcPathId = DataCenter.vipData:getConstConfig("func_path_id", 1);
    DataCenter.funcPathUtil:gotoFunction(funcPathId);
end

























Lua_VipBtnItem = class("Lua_VipBtnItem", Lua_ListCell);

function Lua_VipBtnItem:ctor(p)
    self:superCall("ctor", p, "VipBtnItem_skin");
end

function Lua_VipBtnItem:buildShowItem()
    self:superCall("buildShowItem");

    self.itemIcon = UICreate.createUIAtlasImage(self.content, "", "", 33, -10, 0, 0);
    self.itemIcon.siblingIndex = 1;
end

function Lua_VipBtnItem:dispose()
    if self.itemIcon ~= nil then
        self.itemIcon:dispose();
        self.itemIcon = nil;
    end
    if self.redDotEff ~= nil then
        self.redDotEff:dispose();
        self.redDotEff = nil;
    end

    self.data = nil;
    self:superCall("dispose");
end

function Lua_VipBtnItem:setData(data)
    self.data = data;
    if data == nil then return end;
    
    self.titleTxt.text = LanUtil.formateStr(320008, data.id);
    self.itemTxt.text = data.vip_btn_des[1];

    local itemVo = Lua_ToolVo.new(data.vip_btn_des[2]);
    self.itemIcon:setAltas(itemVo.atlas, itemVo.sprite);
    self.itemIcon:resetSize();

    self.signTxt:setEnable(DataCenter.vipData.level == data.id);
    self.lockIcon:setEnable(data.rewardState == 0);

    self:checkRedDot(data.rewardState == 1);
end

function Lua_VipBtnItem:onPressClick()
    Lua_MsgUtil.callFunc("VIPLEVEL_SELECT", self.data);
    return true;
end

function Lua_VipBtnItem:onSelectionChange(val)
    self:superCall("onSelectionChange", val);

    if val then
        self.btnBg:setAltas("vip_atlas", "ui_vip_window_01");
        self.itemTxt.colorStr = Lua_ColorDefine.transColorStr("5e4b42");
        self.signTxt.colorStr = Lua_ColorDefine.transColorStr("5e4b42");
    else
        self.btnBg:setAltas("vip_atlas", "ui_vip_window_02");
        self.itemTxt.colorStr = Lua_ColorDefine.transColorStr("ece7e9");
        self.signTxt.colorStr = Lua_ColorDefine.transColorStr("a6a1a0");
    end
end

function Lua_VipBtnItem:checkRedDot(bShow)
    if self.redDotEff == nil then
        self.redDotEff = Lua_RedPointIcon.new(self.content);
        self.redDotEff:createRedPointImg();
        self.redDotEff:setLocation(92, 52, 0);
    end
    self.redDotEff:updateRedPointShow(bShow)
end


























Lua_VipPrivilegeItem = class("Lua_VipPrivilegeItem", Lua_DragContainerItem);

function Lua_VipPrivilegeItem:ctor(sub)
    self:superCall("ctor", sub);
end

function Lua_VipPrivilegeItem:buildShowItem()
    self:superCall("buildShowItem");

    self.showList = Array();
    self.hideList = Array();
end

function Lua_VipPrivilegeItem:dispose()
    if self.showList ~= nil then
        self.showList:dispose();
        self.showList:clear();
        self.showList = nil;
    end
    if self.hideList ~= nil then
        self.hideList:dispose();
        self.hideList:clear();
        self.hideList = nil;
    end
    self:superCall("dispose");
end

function Lua_VipPrivilegeItem:setData(data)
    if data == nil then return end
    
    self:returnToHideList();

    local arr = string.split(data, "\n");
    local len = arr:getSize();
    local itemHeight = 43;
    self.showHight = len * itemHeight;

    local item;
    for i = 1, len do
        item = self:createItem();
        item:setData(arr[i]);
        item:setLocation(0, -itemHeight * (i - 1) - itemHeight / 2 + self.showHight / 2, 0);
    end
end

function Lua_VipPrivilegeItem:createItem()
    local item;
    if self.hideList:getSize() > 0 then
        item = self.hideList:shift();
    else
        item = Lua_VipPrivilegeDes.new(self.content);
    end
    item:setEnable(true);
    self.showList:add(item);
    return item;
end

function Lua_VipPrivilegeItem:returnToHideList()
    local item;
    local len = self.showList:getSize();
    for i = 1, len do
        item = self.showList:shift();
        item:setEnable(false);
        self.hideList:add(item);
    end
end

function Lua_VipPrivilegeItem:getWidth()
    return 450;
end

function Lua_VipPrivilegeItem:getHeight()
    return self.showHight;
end

















Lua_VipPrivilegeDes = class("Lua_VipPrivilegeDes", Lua_DisplayObject);

function Lua_VipPrivilegeDes:ctor(p)
    self:superCall("ctor", p);
end

function Lua_VipPrivilegeDes:buildShowItem()
    self:superCall("buildShowItem");

    self.icon = UICreate.createUIAtlasImage(self.content, nil, nil, -180, 0, 0, 0);
    self.icon.pivot = UIUtils.Pivot.Right;

    self.label = UICreate.createLabel(self.content, nil, -175, 0, 200, 35, 24);
    self.label.alignmentValue = 0;
    self.label.pivot = UIUtils.Pivot.Left;
    self.label.fontStyle = UnityEngine.FontStyle.Bold;
    self.label.horizontalOverflowValue = 1;
end

function Lua_VipPrivilegeDes:dispose()
    if self.icon ~= nil then
        self.icon:dispose();
        self.icon = nil;
    end
    if self.label ~= nil then
        self.label:dispose();
        self.label = nil;
    end
    self:superCall("dispose");
end

function Lua_VipPrivilegeDes:setData(data)
    local startIdx, endIdx = string.find(data, "〖", 1);
    if startIdx ~= nil then
        self.icon:setAltas("common_altas_2", "ui_common_label_25");
    else
        self.icon:setAltas("vip_atlas", "ui_vip_label_01");
    end
    self.icon:resetSize();

    self.label.text = LanUtil.formateStr(320009, string.gsub(data, "〖", ""));
end















Lua_VipRewardItem = class("Lua_VipRewardItem", Lua_ListCell);

function Lua_VipRewardItem:ctor(p)
    self:superCall("ctor", p);
end

function Lua_VipRewardItem:buildShowItem()
    self:superCall("buildShowItem");

    self.tool = Lua_ItemIcon.new(self.content);
    self.tool:setScale(0.7, 0.7, 0.7);
end

function Lua_VipRewardItem:dispose(go)
    if self.tool ~= nil then
        self.tool:dispose();
        self.tool = nil;
    end
    self:superCall("dispose");
end

function Lua_VipRewardItem:setData(data)
    self.itemVo = Lua_ToolVo.createToolVo(data[1], data[2]);
    self.tool:setData(self.itemVo);
end

function Lua_VipRewardItem:onPressClick(go)
    DataCenter.packUtil:showItemInfo(self.itemVo);
end























