-- 每周礼包
Lua_WeeklyGiftPanel = class("Lua_WeeklyGiftPanel", Lua_DisplayObject);
function Lua_WeeklyGiftPanel:ctor(p)
	self:superCall("ctor", p, "WeeklyGiftPanel_skin");
end

function Lua_WeeklyGiftPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardBg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 1160 + self.adaptHeight);
	self.bannerTxt:setLangValue(202707);

	self.giftList = Lua_DragList.new(self.content, 635, 725 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.giftList:setListCell(Lua_WeeklyGiftItem, 635, 145, 1);
	self.giftList:setLocation(0, -70, 0);

	self:addLuaEvent("UPDATE_WEEKLYGIFT_INFO", self, self.updateGiftInfo);
	Lua_ProxyManager.getProxy("Lua_RaccoonMartProxy"):sWeeklyGiftInInfo();
end

function Lua_WeeklyGiftPanel:setData(data)
end

function Lua_WeeklyGiftPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	self.rewardBg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 1160 + adaptHeight);
	self.giftList:setContentRect(635, 725 + adaptHeight);
end

function Lua_WeeklyGiftPanel:updateGiftInfo()
	self.giftList:setArrayData(DataCenter.weeklyGiftData:getWeeklyGiftInfo());

	self:startTimer();
	self:updateLeftTime();
end

function Lua_WeeklyGiftPanel:startTimer()
	if self.countDown ~= true then
		self.countDown = true;
		Lua_CommonUtil.addTimer("Lua_WeeklyGiftPanel", 1, self, self.updateLeftTime);
	end
end

function Lua_WeeklyGiftPanel:updateLeftTime()
	local remainTime = DataCenter.weeklyGiftData.nextWeek - DataCenter.roleData.serverTime;
	if remainTime <= 0 then
		self.leftTimeTxt.text = LanUtil.formateStr(202708, "00时00分00秒");
		self:endTimer();
		return;
	end
	self.leftTimeTxt.text = LanUtil.formateStr(202708, Lua_TimeTransform.transSeconds1(remainTime, true, true, true));
end

function Lua_WeeklyGiftPanel:endTimer()
	if self.countDown == true then
		self.countDown = false;
		Lua_CommonUtil.removeTimer(self, self.updateLeftTime);
	end
end

function Lua_WeeklyGiftPanel:dispose()
	if self.giftList ~= nil then
		self.giftList:dispose();
		self.giftList = nil;
	end
	self:endTimer();

	self:superCall("dispose");
end





--------------------------------------------------





Lua_WeeklyGiftItem = class("Lua_WeeklyGiftItem", Lua_ListCell);
function Lua_WeeklyGiftItem:ctor(p)
    self:superCall("ctor", p, "WeeklyGiftItem_skin");
end

function Lua_WeeklyGiftItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_DragList.new(self.content, 230, 112, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_ItemIconCell, 112, 112, 1);
	self.rewardList:setLocation(-180, -15, 0);
	self.rewardList:setCellSpacing(5, 0);
	self.rewardList:setScale(0.8, 0.8, 0.8);

	self.stateBtn:addClickFuntion(self, self.onBuyClick);
end

function Lua_WeeklyGiftItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.tipsTxt.text = data.title;
	self.conditionsTipsTxt.text = LanUtil.formateStr(202709, data.curLimitTimes);

	if data.recharge == 0 then
		self.stateBtn:setLangValue(202704);
	else
		self.stateBtn.label = LanUtil.formateStr(202710, data.recharge);
	end

	local rewardKey = DataCenter.weeklyGiftData.rewardKey;
	local rewardInfo = getConfig({"week_gift", data.id, rewardKey});
	local tvo;
	local rewardArr = Array();
	for i=1, #rewardInfo do
		tvo = Lua_ToolVo.createToolVo(rewardInfo[i][1], rewardInfo[i][2]);
		rewardArr:add(tvo);
	end
	self.rewardList:setArrayData(rewardArr);
	self.rewardList:setContentRect(115 * rewardArr:getSize(), 112);
	self.rewardList:setLocation(-60 - 60 * rewardArr:getSize(), -15, 0);
	self.rewardList.canDrag = rewardArr:getSize() > 3;
	
	self.stateBtn:setEnable(data.curLimitTimes > 0);
	self.sellOutSp:setEnable(data.curLimitTimes <= 0);
	self:showRedDot(data.recharge == 0 and data.curLimitTimes > 0);
end

function Lua_WeeklyGiftItem:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(287, 17, 0);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_WeeklyGiftItem:onBuyClick(go)
	if self.data.recharge == 0 then
		Lua_ProxyManager.getProxy("Lua_RaccoonMartProxy"):sGetWeeklyGiftReward(self.data.id);
	else
		local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(self.data.id);
		DataCenter.sdkInterface:PointOut(1, tonumber(rechargeInfo.money), tonumber(rechargeInfo.money_type),
				tonumber(rechargeInfo.id), rechargeInfo.gift_name, rechargeInfo.gold);
	end
end

function Lua_WeeklyGiftItem:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end